==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/DebugSettingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.DebugSettingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The debug setting.
 * @property detailLevel Specifies the type of information to log for debugging. The permitted values are none, requestContent, responseContent, or both requestContent and responseContent separated by a comma. The default is none. When setting this value, carefully consider the type of information you are passing in during deployment. By logging information about the request or response, you could potentially expose sensitive data that is retrieved through the deployment operations.
 */
public data class DebugSettingArgs(
    public val detailLevel: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.resources.inputs.DebugSettingArgs> {
    override fun toJava(): com.pulumi.azurenative.resources.inputs.DebugSettingArgs =
        com.pulumi.azurenative.resources.inputs.DebugSettingArgs.builder()
            .detailLevel(detailLevel?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DebugSettingArgs].
 */
@PulumiTagMarker
public class DebugSettingArgsBuilder internal constructor() {
    private var detailLevel: Output<String>? = null

    /**
     * @param value Specifies the type of information to log for debugging. The permitted values are none, requestContent, responseContent, or both requestContent and responseContent separated by a comma. The default is none. When setting this value, carefully consider the type of information you are passing in during deployment. By logging information about the request or response, you could potentially expose sensitive data that is retrieved through the deployment operations.
     */
    @JvmName("cwycvbrtqvosjkve")
    public suspend fun detailLevel(`value`: Output<String>) {
        this.detailLevel = value
    }

    /**
     * @param value Specifies the type of information to log for debugging. The permitted values are none, requestContent, responseContent, or both requestContent and responseContent separated by a comma. The default is none. When setting this value, carefully consider the type of information you are passing in during deployment. By logging information about the request or response, you could potentially expose sensitive data that is retrieved through the deployment operations.
     */
    @JvmName("ydtdafxhxeuawlsk")
    public suspend fun detailLevel(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.detailLevel = mapped
    }

    internal fun build(): DebugSettingArgs = DebugSettingArgs(
        detailLevel = detailLevel,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/DebugSettingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.DebugSettingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The debug setting.
 * @property detailLevel Specifies the type of information to log for debugging. The permitted values are none, requestContent, responseContent, or both requestContent and responseContent separated by a comma. The default is none. When setting this value, carefully consider the type of information you are passing in during deployment. By logging information about the request or response, you could potentially expose sensitive data that is retrieved through the deployment operations.
 */
public data class DebugSettingArgs(
    public val detailLevel: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.resources.inputs.DebugSettingArgs> {
    override fun toJava(): com.pulumi.azurenative.resources.inputs.DebugSettingArgs =
        com.pulumi.azurenative.resources.inputs.DebugSettingArgs.builder()
            .detailLevel(detailLevel?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DebugSettingArgs].
 */
@PulumiTagMarker
public class DebugSettingArgsBuilder internal constructor() {
    private var detailLevel: Output<String>? = null

    /**
     * @param value Specifies the type of information to log for debugging. The permitted values are none, requestContent, responseContent, or both requestContent and responseContent separated by a comma. The default is none. When setting this value, carefully consider the type of information you are passing in during deployment. By logging information about the request or response, you could potentially expose sensitive data that is retrieved through the deployment operations.
     */
    @JvmName("vevwsjejqfuqctvi")
    public suspend fun detailLevel(`value`: Output<String>) {
        this.detailLevel = value
    }

    /**
     * @param value Specifies the type of information to log for debugging. The permitted values are none, requestContent, responseContent, or both requestContent and responseContent separated by a comma. The default is none. When setting this value, carefully consider the type of information you are passing in during deployment. By logging information about the request or response, you could potentially expose sensitive data that is retrieved through the deployment operations.
     */
    @JvmName("gryctglidgtatyxg")
    public suspend fun detailLevel(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.detailLevel = mapped
    }

    internal fun build(): DebugSettingArgs = DebugSettingArgs(
        detailLevel = detailLevel,
    )
}
